==> org-lsst-ccs-subsystem-fcs-gui-2.1.4-sources.jar: org/lsst/ccs/subsystems/fcs/carousel/ui/CarouselSocketPanel.java <==
/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */
package org.lsst.ccs.subsystems.fcs.carousel.ui;

import java.awt.Color;
import java.awt.Dimension;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.util.Map;
import javax.swing.BorderFactory;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.SwingUtilities;
import org.lsst.ccs.bus.data.ConfigurationInfo;
import org.lsst.ccs.subsystems.fcs.FCSCst;
import org.lsst.ccs.subsystems.fcs.StatusDataPublishedByCarouselClamp;
import org.lsst.ccs.subsystems.fcs.StatusDataPublishedByCarouselSocket;
import org.lsst.ccs.subsystems.fcs.ui.commons.DigitalSwitch;
import org.lsst.ccs.subsystems.fcs.ui.commons.FilterPanel;
import org.lsst.ccs.subsystems.fcs.ui.commons.Tools;
import static org.lsst.ccs.subsystems.fcs.ui.commons.Tools.BIG_FONT;
import static org.lsst.ccs.subsystems.fcs.ui.commons.Tools.greenColor;
import static org.lsst.ccs.subsystems.fcs.ui.commons.Tools.insets_std;
import static org.lsst.ccs.subsystems.fcs.ui.commons.Tools.VERY_BIG_FONT;

/**
 * A Panel for a carousel socket.
 * There are 2 carousel clamps on a socket.
 * @author virieux
 */
public class CarouselSocketPanel extends JPanel {
    private static final long serialVersionUID = 6352712511682293959L;
    
    private CarouselGUI subs;
    private String socketName;
    private String clampXminusName;
    private String clampXplusName;
    
    
    private JPanel sensorsPanel;
    
    private CarouselClampPanel clampXminusPanel;
    private CarouselClampPanel clampXplusPanel;
    private FilterPanel filterPanel;
    
    /*Clamp State Panel*/
    private JPanel clampsStatePanel;
    private final JLabel clampsState = new JLabel("UNKNOWN STATE");
    private final JLabel clampsStateLabel = new JLabel("Clamps State :");
    private final JLabel xMinusLabel = new JLabel("X-");
    private final JLabel xMinusLabel2 = new JLabel("X-");
    private final JLabel xPlusLabel = new JLabel("X+");
    private final JLabel xPlusLabel2 = new JLabel("X+");
    
    /*General Information Panel*/
    private JPanel generalInfoPanel;
    private final JLabel nLabel = new JLabel("Name: ");
    private final JLabel nameLabel = new JLabel("socketXXX");
    private final JLabel pLabel = new JLabel("Position on Carousel: ");   
    private final JLabel positionOnCarouselLabel = new JLabel("0.0");
    private final JLabel sLabel = new JLabel("Carousel position at STANDBY: ");   
    private final JLabel standbyPositionLabel = new JLabel("99.999");
    
    /*Actual Position Panel*/
    private JPanel actualPositionPanel;
    private final JLabel apLabel = new JLabel("Actual position: ");
    private final JLabel actualPositionLabel = new JLabel("777.888");
    private final JLabel standbyLabel = new JLabel(FCSCst.NOT_AT_STANDBY);
    private final DigitalSwitch standbySwitch = new DigitalSwitch();

    /**
     * 
     * Create a CarouselSocketPanel with no parameter.
     * Initialize fields socketName, clampXminusName and clampXplusName.
     * Just for tests.
     */
    public CarouselSocketPanel() {
        socketName = "socket99";
        clampXminusName = "clampXminus99";
        clampXplusName = "clampXplus99";
        initComponents();
    }


    public CarouselSocketPanel(String socketName) {
        this.socketName = socketName;
        nameLabel.setText(socketName);
        
        /*To find the name of the clamps needed to initialize the clampPanels.*/
        char num = socketName.charAt(socketName.length()-1);        
        clampXminusName = "clampXminus" + num;
        clampXplusName = "clampXplus" + num;
        initComponents();
    }
    
    
    
    public CarouselSocketPanel(CarouselGUI subs) {
        this.subs = subs;
    }

    public void setSubsystem(CarouselGUI subs) {
        this.subs = subs;
    }
    
    

    /**
     * Initialize the GUI with the configuration data.
     * 
     * @param configInfo
     */
    public void initializeGui(ConfigurationInfo configInfo) {
        Map<String, String> config = configInfo.getCurrentValuesForComponent(socketName); 
        positionOnCarouselLabel.setText(Tools.getText(config, socketName,"positionOnCarousel"));
        standbyPositionLabel.setText(Tools.getText(config, socketName,"standbyPosition"));
        clampXminusPanel.initializeGui(configInfo);
        clampXplusPanel.initializeGui(configInfo);
    }
    
    
    
    
    public void updateSocket(StatusDataPublishedByCarouselSocket s) {
        SwingUtilities.invokeLater(new UpdateSocket(s));
    }
    
    /**
     * A Runnable to updateSocket this panel from a StatusDataPublishedByCarouselSocket.
     */
    public class UpdateSocket implements Runnable {
        private StatusDataPublishedByCarouselSocket s;

        public UpdateSocket(StatusDataPublishedByCarouselSocket s) {
            this.s = s;
        }

        @Override
        public void run() {
            actualPositionLabel.setText(Double.toString(s.getActualPosition()));
            if (s.isAtStandby()) {
                standbyLabel.setText(FCSCst.AT_STANDBY);
                standbySwitch.setColor(greenColor);
            } else {
                standbyLabel.setText(FCSCst.NOT_AT_STANDBY);
                standbySwitch.setColor(Color.darkGray);
            }
            clampsState.setText(s.getClampState().toString());
            clampsState.setForeground(s.getClampState().getColor());
            if (s.isEmpty()) {
                filterPanel.setIsFilterInHouse(false, FCSCst.NO_FILTER);
            } else {
                filterPanel.setIsFilterInHouse(true,s.getFilterName());
            }
        }
        
    }
    
    
    
    /**
     * Update the socket panel from data published by a carousel clamp.
     * It can be a clampXminus or a clampXplus.
     * @param s 
     */
    public void update(StatusDataPublishedByCarouselClamp s) {
        //TODO when the filter goes to the autochanger this has to be changed.
        FCSCst.FCSLOG.debug(getName() + " updating from carousel clamp data:" + s.toString());
        if (s.getName().contains("Xminus")) {
            clampXminusPanel.updateClamp(s);
        } else if (s.getName().contains("Xplus")) {
            clampXplusPanel.updateClamp(s);
        } else {
            FCSCst.FCSLOG.error("Error in clamps name on STATUS bus:" + s.getName());
        }
    }
    
    
    // <editor-fold defaultstate="collapsed" desc="Form description">                          
    private void initComponents() {
        /**
         * First init the JButtons
         */
        //TODO
        
        /**
         * X- and X+ label
         */        
        xMinusLabel.setFont(VERY_BIG_FONT); // NOI18N      
        xMinusLabel2.setFont(VERY_BIG_FONT); // NOI18N
        xPlusLabel2.setFont(VERY_BIG_FONT); // NOI18N       
        xPlusLabel.setFont(VERY_BIG_FONT); // NOI18N
        /**
         ******************************************************************************
         ** General Informations Panel
         * *****************************************************************************
         */
        generalInfoPanel = new JPanel();
        generalInfoPanel.setBorder(BorderFactory.createTitledBorder("General Informations"));
        generalInfoPanel.setLayout(new GridBagLayout());
        GridBagConstraints gbc3 = new GridBagConstraints();
        gbc3.insets = insets_std;
        //first colomn
        gbc3.gridx = 0;
        gbc3.gridy = 0;
        gbc3.anchor = GridBagConstraints.LINE_START;

        generalInfoPanel.add(nLabel, gbc3);
        gbc3.gridy++;
        generalInfoPanel.add(pLabel, gbc3);
        gbc3.gridy++;
        generalInfoPanel.add(sLabel, gbc3);
        //second colomn
        gbc3.gridx++;
        gbc3.gridy = 0;
        gbc3.anchor = GridBagConstraints.LINE_END;
        generalInfoPanel.add(nameLabel, gbc3);
        nameLabel.setFont(BIG_FONT);
        gbc3.gridy++;
        generalInfoPanel.add(positionOnCarouselLabel, gbc3);  
        gbc3.gridy++;
        generalInfoPanel.add(standbyPositionLabel, gbc3);        
        /**
         ******************************************************************************
         ** end of General Informations Panel
         * *****************************************************************************
         */
        
        /**
         ******************************************************************************
         ** Actual Position Panel
         * *****************************************************************************
         */
        actualPositionPanel = new JPanel();
        actualPositionPanel.setBorder(BorderFactory.createLineBorder(Color.yellow));
        actualPositionPanel.setLayout(new GridBagLayout());
        actualPositionPanel.setMinimumSize(new Dimension(100,50));
        GridBagConstraints gbc1 = new GridBagConstraints();
        gbc3.insets = insets_std;
        //first colomn
        gbc1.gridx = 0;
        gbc1.gridy = 0;
        gbc1.anchor = GridBagConstraints.LINE_START;
        actualPositionPanel.add(apLabel,gbc1);
        gbc1.gridy++;
        actualPositionPanel.add(standbyLabel,gbc1);
        //second colomn
        gbc1.gridx++;
        gbc1.gridy = 0;
        gbc1.anchor = GridBagConstraints.LINE_END;
        actualPositionPanel.add(actualPositionLabel, gbc1);
        gbc1.gridy++;
        standbySwitch.setColor(Color.gray);
        actualPositionPanel.add(standbySwitch,gbc1);

        /**
         ******************************************************************************
         ** end of Actual Position Panel
         * *****************************************************************************
         */
        
        /**
         ******************************************************************************
         ** Clamps State Panel
         * *****************************************************************************
         */
        clampsStatePanel = new JPanel();
        clampsState.setFont(BIG_FONT); // NOI18N
        clampsState.setBorder(BorderFactory.createEtchedBorder(new java.awt.Color(255, 255, 255), new java.awt.Color(255, 255, 255)));
        clampsStatePanel.setLayout(new GridBagLayout());
        GridBagConstraints gbc2 = new GridBagConstraints();
        gbc2.insets = insets_std;
        gbc2.gridx = 0;
        gbc2.gridy = 0;
        clampsStatePanel.add(clampsStateLabel, gbc2);
        gbc2.gridx++;
        clampsStatePanel.add(clampsState, gbc2);
        /**
         ******************************************************************************
         ** end of Clamps State Panel
         * *****************************************************************************
         */
        
        /**
         ******************************************************************************
         ** Carousel ClampXminus Panel
         * *****************************************************************************
         */
        clampXminusPanel = new CarouselClampPanel(clampXminusName);
        /**
         ******************************************************************************
         ** end of Carousel ClampXminus Panel
         * *****************************************************************************
         */
        
        /**
         ******************************************************************************
         ** Carousel ClampXplus Panel
         * *****************************************************************************
         */
        clampXplusPanel = new CarouselClampPanel(clampXplusName);
        /**
         ******************************************************************************
         ** end of Carousel ClampXplus Panel
         * *****************************************************************************
         */
         /**
         ******************************************************************************
         ** Filter Panel
         * *****************************************************************************
         */
        filterPanel = new FilterPanel();
        filterPanel.setSize(150);
        filterPanel.setIsFilterInHouse(false, FCSCst.NO_FILTER);
        /**
         ******************************************************************************
         ** end of Filter Panel
         * *****************************************************************************
         */
        /**
         ******************************************************************************
         ** Whole Panel
         * *****************************************************************************
         */
        /*General Information Panel*/
        setBorder(BorderFactory.createLineBorder(Color.PINK));
        setLayout(new java.awt.GridBagLayout());
        GridBagConstraints gbc = new GridBagConstraints();
        gbc.insets = insets_std;
        gbc.anchor = GridBagConstraints.NORTHWEST;

        gbc.gridx = 0;
        gbc.gridy = 0;
        add(generalInfoPanel, gbc); 
        
        gbc.gridx++;
        add(actualPositionPanel);
        
//        gbc.gridx++;
//        add(filterPanel, gbc);
        
        /*Clamps State  Panel with X- and X+*/
        gbc.anchor = GridBagConstraints.WEST;
        gbc.gridx = 0;
        gbc.gridy++;
        add(xMinusLabel, gbc);
        
        gbc.gridx++;
        //gbc.gridwidth = 4;
        gbc.anchor = GridBagConstraints.CENTER;
        add(clampsStatePanel, gbc);
        
        gbc.anchor = GridBagConstraints.EAST;
        gbc.gridx = 3;
        add(xPlusLabel, gbc);
        
        /*Clamps Panel and Filter Panel*/
        gbc.gridx=0;
        gbc.gridy++;
        add(clampXminusPanel, gbc);
        gbc.gridx++;
        add(filterPanel, gbc);
        gbc.gridx++;
        add(clampXplusPanel, gbc);
        
        /*Last line with X- and X+*/
        gbc.anchor = GridBagConstraints.WEST;
        gbc.gridx = 0;
        gbc.gridy++;
        add(xMinusLabel2, gbc);
        
        
        gbc.anchor = GridBagConstraints.EAST;
        gbc.gridx = 3;
        add(xPlusLabel2, gbc);

        /**
         ******************************************************************************
         ** end of Whole Panel
         * *****************************************************************************
         */
    }
    
    @Override
    public String toString() {
        if (socketName == null) return "Unamed socket";
        else return socketName;
    }
        
    /**
     * Just to test the Panel.
     * @param argv 
     */
    public static void main(String[] argv) {

        CarouselSocketPanel d = new CarouselSocketPanel();
        JFrame frame = new JFrame("Test");
        frame.setContentPane(d);
        frame.pack();
        frame.setVisible(true);
        frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);

    }
    
    

    
    
    
}

==> org-lsst-ccs-subsystem-fcs-gui-4.0.0-sources.jar: org/lsst/ccs/subsystems/fcs/carousel/ui/CarouselSocketPanel.java <==
/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */
package org.lsst.ccs.subsystems.fcs.carousel.ui;

import java.awt.Color;
import java.awt.Dimension;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.util.Map;
import javax.swing.BorderFactory;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.SwingUtilities;
import org.lsst.ccs.bus.data.ConfigurationInfo;
import org.lsst.ccs.subsystems.fcs.FCSCst;
import org.lsst.ccs.subsystems.fcs.FcsEnumerations;
import org.lsst.ccs.subsystems.fcs.StatusDataPublishedByCarouselClamp;
import org.lsst.ccs.subsystems.fcs.StatusDataPublishedByCarouselSocket;
import org.lsst.ccs.subsystems.fcs.ui.commons.DigitalSwitch;
import org.lsst.ccs.subsystems.fcs.ui.commons.FilterPanel;
import org.lsst.ccs.subsystems.fcs.ui.commons.Tools;
import static org.lsst.ccs.subsystems.fcs.ui.commons.Tools.UNKNOWN_STATE;
import static org.lsst.ccs.subsystems.fcs.ui.commons.Tools.BIG_FONT;
import static org.lsst.ccs.subsystems.fcs.ui.commons.Tools.UNKNOWN_VALUE;
import static org.lsst.ccs.subsystems.fcs.ui.commons.Tools.greenColor;
import static org.lsst.ccs.subsystems.fcs.ui.commons.Tools.insets_std;
import static org.lsst.ccs.subsystems.fcs.ui.commons.Tools.VERY_BIG_FONT;

/**
 * A Panel for a carousel socket.
 * There are 2 carousel clamps on a socket.
 * @author virieux
 */
public class CarouselSocketPanel extends JPanel {
    private static final long serialVersionUID = 6352712511682293959L;
    
    private InterfaceCarouselGUI subs;
    private String socketName;
    private String clampXminusName;
    private String clampXplusName;
    
    
    private JPanel sensorsPanel;
    
    private CarouselClampPanel clampXminusPanel;
    private CarouselClampPanel clampXplusPanel;
    private FilterPanel filterPanel;
    
    /*Clamp State Panel*/
    private JPanel clampsStatePanel;
    private final JLabel clampsState = new JLabel(UNKNOWN_STATE);
    private final JLabel clampsStateLabel = new JLabel("Clamps State :");
    private final JLabel xMinusLabel = new JLabel("X-");
    private final JLabel xMinusLabel2 = new JLabel("X-");
    private final JLabel xPlusLabel = new JLabel("X+");
    private final JLabel xPlusLabel2 = new JLabel("X+");
    
    /*General Information Panel*/
    private JPanel generalInfoPanel;
    private final JLabel nLabel = new JLabel("Name: ");
    private final JLabel nameLabel = new JLabel("socketXXX");
    private final JLabel pLabel = new JLabel("Position on Carousel: ");   
    private final JLabel positionOnCarouselLabel = new JLabel("0.0");
    private final JLabel sLabel = new JLabel("Carousel position at STANDBY: ");   
    private final JLabel standbyPositionLabel = new JLabel(UNKNOWN_VALUE);
    
    /*Actual Position Panel*/
    private JPanel actualPositionPanel;
    private final JLabel apLabel = new JLabel("Actual position: ");
    private final JLabel actualPositionLabel = new JLabel(UNKNOWN_VALUE);
    private final JLabel standbyLabel = new JLabel(FCSCst.NOT_AT_STANDBY);
    private final DigitalSwitch standbySwitch = new DigitalSwitch();

    /**
     * 
     * Creates a CarouselSocketPanel with no parameter.
     * Initializes fields socketName, clampXminusName and clampXplusName.
     * Just for tests.
     */
    public CarouselSocketPanel() {
        socketName = "socket99";
        setName(socketName+"Panel");
        clampXminusName = "clampXminus99";
        clampXplusName = "clampXplus99";
        initComponents();
    }

    /**
     * Creates a CarouselSocketPanel with a socketName.
     * @param socketName 
     */
    public CarouselSocketPanel(String socketName) {
        this.socketName = socketName;
        setName(socketName+"Panel");
        nameLabel.setText(socketName);
        
        /*To find the name of the clamps needed to initialize the clampPanels.*/
        char num = socketName.charAt(socketName.length()-1);        
        clampXminusName = "clampXminus" + num;
        clampXplusName = "clampXplus" + num;
        initComponents();
    }

    public void setSubsystem(InterfaceCarouselGUI subs) {
        this.subs = subs;
    }
    
    

    /**
     * Initialize the GUI with the configuration data.
     * 
     * @param configInfo
     */
    public void initializeGui(ConfigurationInfo configInfo) {
        Map<String, String> config = configInfo.getCurrentValuesFor(socketName); 
        positionOnCarouselLabel.setText(config.get("positionOnCarousel"));
        standbyPositionLabel.setText(config.get("standbyPosition"));
        clampXminusPanel.initializeGui(configInfo);
        clampXplusPanel.initializeGui(configInfo);
    }
    
    
    
    
    public void updateSocket(StatusDataPublishedByCarouselSocket s) {
        SwingUtilities.invokeLater(new UpdateSocket(s));
    }
    
    /**
     * A Runnable to updateSocket this panel from a StatusDataPublishedByCarouselSocket.
     */
    public class UpdateSocket implements Runnable {
        private StatusDataPublishedByCarouselSocket s;

        public UpdateSocket(StatusDataPublishedByCarouselSocket s) {
            this.s = s;
        }

        @Override
        public void run() {
            actualPositionLabel.setText(Double.toString(s.getActualPosition()));
            if (s.isAtStandby()) {
                standbyLabel.setText(FCSCst.AT_STANDBY);
                standbySwitch.setColor(greenColor);
            } else {
                standbyLabel.setText(FCSCst.NOT_AT_STANDBY);
                standbySwitch.setColor(Color.darkGray);
            }
            clampsState.setText(s.getClampState().toString());
            clampsState.setForeground(s.getClampState().getColor());
            if (s.isEmpty()) {
                filterPanel.setIsFilterInHouse(false, FCSCst.NO_FILTER);
            } else {
                filterPanel.setIsFilterInHouse(true,s.getFilterName());
            }
        }
        
    }
    
    
    
    /**
     * Update the socket panel from data published by a carousel clamp.
     * It can be a clampXminus or a clampXplus.
     * @param s 
     */
    public void update(StatusDataPublishedByCarouselClamp s) {
        //TODO when the filter goes to the autochanger this has to be changed.
        FCSCst.FCSLOG.debug(getName() + " updating from carousel clamp data:" + s.toString());
        if (s.getName().contains("Xminus")) {
            clampXminusPanel.updateClamp(s);
        } else if (s.getName().contains("Xplus")) {
            clampXplusPanel.updateClamp(s);
        } else {
            FCSCst.FCSLOG.error("Error in clamps name on STATUS bus:" + s.getName());
        }
    }
    
    
    // <editor-fold defaultstate="collapsed" desc="Form description">                          
    private void initComponents() {
        /**
         * First init the JButtons
         */
        //TODO
        
        /**
         * X- and X+ label
         */        
        xMinusLabel.setFont(VERY_BIG_FONT); // NOI18N      
        xMinusLabel2.setFont(VERY_BIG_FONT); // NOI18N
        xPlusLabel2.setFont(VERY_BIG_FONT); // NOI18N       
        xPlusLabel.setFont(VERY_BIG_FONT); // NOI18N
        /**
         ******************************************************************************
         ** General Informations Panel
         * *****************************************************************************
         */
        generalInfoPanel = new JPanel();
        generalInfoPanel.setBorder(BorderFactory.createTitledBorder("General Informations"));
        generalInfoPanel.setLayout(new GridBagLayout());
        GridBagConstraints gbc3 = new GridBagConstraints();
        gbc3.insets = insets_std;
        //first colomn
        gbc3.gridx = 0;
        gbc3.gridy = 0;
        gbc3.anchor = GridBagConstraints.LINE_START;

        generalInfoPanel.add(nLabel, gbc3);
        gbc3.gridy++;
        generalInfoPanel.add(pLabel, gbc3);
        gbc3.gridy++;
        generalInfoPanel.add(sLabel, gbc3);
        //second colomn
        gbc3.gridx++;
        gbc3.gridy = 0;
        gbc3.anchor = GridBagConstraints.LINE_END;
        generalInfoPanel.add(nameLabel, gbc3);
        nameLabel.setFont(BIG_FONT);
        gbc3.gridy++;
        generalInfoPanel.add(positionOnCarouselLabel, gbc3);  
        gbc3.gridy++;
        generalInfoPanel.add(standbyPositionLabel, gbc3);        
        /**
         ******************************************************************************
         ** end of General Informations Panel
         * *****************************************************************************
         */
        
        /**
         ******************************************************************************
         ** Actual Position Panel
         * *****************************************************************************
         */
        actualPositionPanel = new JPanel();
        actualPositionPanel.setBorder(BorderFactory.createLineBorder(Color.yellow));
        actualPositionPanel.setLayout(new GridBagLayout());
        actualPositionPanel.setMinimumSize(new Dimension(100,50));
        GridBagConstraints gbc1 = new GridBagConstraints();
        gbc3.insets = insets_std;
        //first colomn
        gbc1.gridx = 0;
        gbc1.gridy = 0;
        gbc1.anchor = GridBagConstraints.LINE_START;
        actualPositionPanel.add(apLabel,gbc1);
        gbc1.gridy++;
        actualPositionPanel.add(standbyLabel,gbc1);
        //second colomn
        gbc1.gridx++;
        gbc1.gridy = 0;
        gbc1.anchor = GridBagConstraints.LINE_END;
        actualPositionPanel.add(actualPositionLabel, gbc1);
        gbc1.gridy++;
        standbySwitch.setColor(Color.gray);
        actualPositionPanel.add(standbySwitch,gbc1);

        /**
         ******************************************************************************
         ** end of Actual Position Panel
         * *****************************************************************************
         */
        
        /**
         ******************************************************************************
         ** Clamps State Panel
         * *****************************************************************************
         */
        clampsStatePanel = new JPanel();
        clampsState.setFont(BIG_FONT); // NOI18N
        clampsState.setBorder(BorderFactory.createEtchedBorder(new Color(255, 255, 255), new Color(255, 255, 255)));
        clampsStatePanel.setLayout(new GridBagLayout());
        GridBagConstraints gbc2 = new GridBagConstraints();
        gbc2.insets = insets_std;
        gbc2.gridx = 0;
        gbc2.gridy = 0;
        clampsStatePanel.add(clampsStateLabel, gbc2);
        gbc2.gridx++;
        clampsStatePanel.add(clampsState, gbc2);
        /**
         ******************************************************************************
         ** end of Clamps State Panel
         * *****************************************************************************
         */
        
        /**
         ******************************************************************************
         ** Carousel ClampXminus Panel
         * *****************************************************************************
         */
        clampXminusPanel = new CarouselClampPanel(clampXminusName);
        /**
         ******************************************************************************
         ** end of Carousel ClampXminus Panel
         * *****************************************************************************
         */
        
        /**
         ******************************************************************************
         ** Carousel ClampXplus Panel
         * *****************************************************************************
         */
        clampXplusPanel = new CarouselClampPanel(clampXplusName);
        /**
         ******************************************************************************
         ** end of Carousel ClampXplus Panel
         * *****************************************************************************
         */
         /**
         ******************************************************************************
         ** Filter Panel
         * *****************************************************************************
         */
        filterPanel = new FilterPanel();
        filterPanel.setSize(150);
        filterPanel.setIsFilterInHouse(false, FCSCst.NO_FILTER);
        /**
         ******************************************************************************
         ** end of Filter Panel
         * *****************************************************************************
         */
        /**
         ******************************************************************************
         ** Whole Panel
         * *****************************************************************************
         */
        /*General Information Panel*/
        setBorder(BorderFactory.createLineBorder(Color.PINK));
        setLayout(new java.awt.GridBagLayout());
        GridBagConstraints gbc = new GridBagConstraints();
        gbc.insets = insets_std;
        gbc.anchor = GridBagConstraints.NORTHWEST;

        gbc.gridx = 0;
        gbc.gridy = 0;
        add(generalInfoPanel, gbc); 
        
        gbc.gridx++;
        add(actualPositionPanel);
        
//        gbc.gridx++;
//        add(filterPanel, gbc);
        
        /*Clamps State  Panel with X- and X+*/
        gbc.anchor = GridBagConstraints.WEST;
        gbc.gridx = 0;
        gbc.gridy++;
        add(xMinusLabel, gbc);
        
        gbc.gridx++;
        //gbc.gridwidth = 4;
        gbc.anchor = GridBagConstraints.CENTER;
        add(clampsStatePanel, gbc);
        
        gbc.anchor = GridBagConstraints.EAST;
        gbc.gridx = 3;
        add(xPlusLabel, gbc);
        
        /*Clamps Panel and Filter Panel*/
        gbc.gridx=0;
        gbc.gridy++;
        add(clampXminusPanel, gbc);
        gbc.gridx++;
        add(filterPanel, gbc);
        gbc.gridx++;
        add(clampXplusPanel, gbc);
        
        /*Last line with X- and X+*/
        gbc.anchor = GridBagConstraints.WEST;
        gbc.gridx = 0;
        gbc.gridy++;
        add(xMinusLabel2, gbc);
        
        
        gbc.anchor = GridBagConstraints.EAST;
        gbc.gridx = 3;
        add(xPlusLabel2, gbc);

        /**
         ******************************************************************************
         ** end of Whole Panel
         * *****************************************************************************
         */
    }
    
    /**
     * Reset Panel to display default values when subsystem is halted.
     */
    public void resetPanel() {
        clampsState.setText(UNKNOWN_STATE);
        clampsState.setForeground(Color.darkGray);
        actualPositionLabel.setText(UNKNOWN_VALUE);
        standbyLabel.setText(FCSCst.UNKNOWN);
        standbySwitch.setColor(Color.darkGray);
        filterPanel.setIsFilterInHouse(false, FCSCst.NO_FILTER);
        clampXminusPanel.resetPanel();
        clampXplusPanel.resetPanel();
    }
    
    @Override
    public String toString() {
        if (socketName == null) return "Unamed socket";
        else return socketName;
    }
    

        
    /**
     * Just to test the Panel.
     * @param argv 
     */
    public static void main(String[] argv) {

        CarouselSocketPanel d = new CarouselSocketPanel();
        JFrame frame = new JFrame("Test");
        frame.setContentPane(d);
        frame.pack();
        frame.setVisible(true);
        frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);

    }
    
    

    
    
    
}
